from fastapi.testclient import TestClient

from .main import app

client = TestClient(app)


def test_elements() -> None:
    response = client.get("/elements")
    assert response.status_code == 200, response.text
    assert response.headers["content-type"] == "text/html; charset=utf-8"
    assert "@stoplight/elements/web-components.min.js" in response.text
    assert "@stoplight/elements/styles.min.css" in response.text



# SPDX-FileCopyrightText: 2024-present hasansezertasan <hasansezertasan@gmail.com>
#
# SPDX-License-Identifier: MIT
from .elements import Elements as Elements
from .rapidoc import RapiDoc as RapiDoc
from .redoc import ReDoc as ReDoc
from .scalar import Scalar as Scalar
from .swaggerui import SwaggerUI as SwaggerUI



from fastapi.testclient import TestClient

from .main import app

client = TestClient(app)


def test_scalar_plain() -> None:
    response = client.get("/scalar-plain")
    assert response.status_code == 200, response.text
    assert response.headers["content-type"] == "text/html; charset=utf-8"
    assert "@scalar/api-reference" in response.text


def test_scalar_custom() -> None:
    response = client.get("/scalar-custom")
    assert response.status_code == 200, response.text
    assert "https://cdn.jsdelivr.net/npm/@scalar/api-reference" in response.text



from fastapi.testclient import TestClient

from .main import app

client = TestClient(app)


def test_swagger_ui_plain() -> None:
    # Copy of https://github.com/tiangolo/fastapi/blob/be876902554a0bd886167de144f0d593ed2e6ad7/tests/test_application.py#L24-L32
    response = client.get("/swaggerui-plain")
    assert response.status_code == 200, response.text
    assert response.headers["content-type"] == "text/html; charset=utf-8"
    assert "swagger-ui-dist" in response.text
    assert (
        "oauth2RedirectUrl: window.location.origin + '/docs/oauth2-redirect'"
        in response.text
    )


def test_swagger_ui_custom() -> None:
    # Copy of https://github.com/tiangolo/fastapi/blob/be876902554a0bd886167de144f0d593ed2e6ad7/tests/test_tutorial/test_custom_docs_ui/test_tutorial001.py#L20-L26
    response = client.get("/swaggerui-custom")
    assert response.status_code == 200, response.text
    assert (
        "https://unpkg.com/swagger-ui-dist@5.9.0/swagger-ui-bundle.js" in response.text
    )
    assert "https://unpkg.com/swagger-ui-dist@5.9.0/swagger-ui.css" in response.text
    # Copy of https://github.com/tiangolo/fastapi/blob/be876902554a0bd886167de144f0d593ed2e6ad7/tests/test_swagger_ui_init_oauth.py#L17-L23
    assert "ui.initOAuth" in response.text
    assert '"appName": "Test Application"' in response.text
    assert '"clientId": "the-application-clients"' in response.text
    # Copy of https://github.com/tiangolo/fastapi/blob/be876902554a0bd886167de144f0d593ed2e6ad7/tests/test_no_swagger_ui_redirect.py#L15-L21C1
    assert "oauth2RedirectUrl" not in response.text

    # Copy of https://github.com/tiangolo/fastapi/blob/be876902554a0bd886167de144f0d593ed2e6ad7/tests/test_tutorial/test_configure_swagger_ui/test_tutorial001.py#L8-L35 and https://github.com/tiangolo/fastapi/blob/be876902554a0bd886167de144f0d593ed2e6ad7/tests/test_tutorial/test_configure_swagger_ui/test_tutorial002.py#L8-L38 and https://github.com/tiangolo/fastapi/blob/be876902554a0bd886167de144f0d593ed2e6ad7/tests/test_tutorial/test_configure_swagger_ui/test_tutorial003.py#L8-L38
    assert (
        '"deepLinking": false,' in response.text
    ), "overridden configs should be preserved"
    assert (
        '"deepLinking": true' not in response.text
    ), "overridden configs should not include the old value"
    assert (
        '"syntaxHighlight": false' in response.text
    ), "syntaxHighlight should be included and converted to JSON"
    assert (
        '"syntaxHighlight.theme": "obsidian"' in response.text
    ), "parameters with middle dots should be included in a JSON compatible way"
    assert (
        '"dom_id": "#swagger-ui"' in response.text
    ), "default configs should be preserved"
    assert "presets: [" in response.text, "default configs should be preserved"
    assert (
        "SwaggerUIBundle.presets.apis," in response.text
    ), "default configs should be preserved"
    assert (
        "SwaggerUIBundle.SwaggerUIStandalonePreset" in response.text
    ), "default configs should be preserved"
    assert (
        '"layout": "BaseLayout",' in response.text
    ), "default configs should be preserved"
    assert (
        '"showExtensions": true,' in response.text
    ), "default configs should be preserved"
    assert (
        '"showCommonExtensions": true,' in response.text
    ), "default configs should be preserved"



from dataclasses import dataclass, field

from typing_extensions import Annotated, Doc, List


@dataclass
class Base:
    """Base class for alternative API docs."""

    title: Annotated[
        str,
        Doc(
            """
            The HTML `<title>` content, normally shown in the browser tab.
            """
        ),
    ]
    js_url: Annotated[
        str,
        Doc(
            """
            The URL to use to load the JavaScript.
            It is normally set to a CDN URL.
            """
        ),
    ]
    openapi_url: Annotated[
        str,
        Doc(
            """
            The OpenAPI URL that page should load and use.
            Default URL `/openapi.json`.
            """
        ),
    ] = "/openapi.json"
    head_js_urls: Annotated[
        List[str],
        Doc(
            """
            A list of URLs to JavaScript files that should be loaded in the `<head>` tag.
            """
        ),
    ] = field(default_factory=list)
    tail_js_urls: Annotated[
        List[str],
        Doc(
            """
            A list of URLs to JavaScript files that should be loaded at the end of the `<body>` tag.
            """
        ),
    ] = field(default_factory=list)
    head_css_urls: Annotated[
        List[str],
        Doc(
            """
            A list of URLs to CSS files that should be loaded in the `<head>` tag.
            """
        ),
    ] = field(default_factory=list)
    favicon_url: Annotated[
        str,
        Doc(
            """
            The URL of the favicon to use. It is normally shown in the browser tab.
            """
        ),
    ] = "/favicon.ico"

    def render(self) -> str:
        """Generate and return the HTML response that leads page for alternative API docs."""
        html_template = self.get_html_template()
        return html_template.format(
            title=self.title,
            favicon_url=self.favicon_url,
            head_css_str=self.get_head_css_str(),
            head_js_str=self.get_head_js_str(),
            tail_js_str=self.get_tail_js_str(),
        )

    def get_html_template(self) -> str:
        """Return the HTML template for the alternative API docs."""
        html = """
        <!DOCTYPE html>
        <html>
            <head>
                <title>{title}</title>
                <link rel="shortcut icon" href="{favicon_url}">
                {head_css_str}
                {head_js_str}
            </head>
            <body>
                {tail_js_str}
            </body>
        </html>
        """
        return html

    def get_tail_js_str(self) -> str:
        """Return the string of JavaScript URLs that should be loaded at the end of the `<body>` tag."""
        string = "\n".join(
            [f'<script src="{url}"></script>' for url in self.tail_js_urls]
        )
        return string

    def get_head_js_str(self) -> str:
        """Return the string of JavaScript URLs that should be loaded in the `<head>` tag."""
        if self.head_js_urls:
            string = "\n".join(
                [f'<script src="{url}"></script>' for url in self.head_js_urls]
            )
        else:
            string = ""
        return string

    def get_head_css_str(self) -> str:
        """Return the string of CSS URLs that should be loaded in the `<head>` tag."""
        if self.head_css_urls:
            string = "\n".join(
                [
                    f'<link type="text/css" rel="stylesheet"  href="{url}">'
                    for url in self.head_css_urls
                ]
            )
        else:
            string = ""
        return string



from dataclasses import dataclass

from typing_extensions import Annotated, Doc

from .base import Base


@dataclass
class Elements(Base):
    """Alternative API docs using Stoplight Elements."""

    js_url: Annotated[
        str,
        Doc(
            """
            The URL to use to load the Stoplight Elements JavaScript.
            It is normally set to a CDN URL.
            """
        ),
    ] = "https://unpkg.com/@stoplight/elements/web-components.min.js"
    css_url: Annotated[
        str,
        Doc(
            """
            The URL to use to load the Stoplight Elements CSS.
            It is normally set to a CDN URL.
            """
        ),
    ] = "https://unpkg.com/@stoplight/elements/styles.min.css"

    def render(self) -> str:
        """Generate and return the HTML response that loads Stoplight Elements for the alternative API docs."""
        self.head_css_urls.insert(0, self.css_url)
        self.head_js_urls.insert(0, self.js_url)
        html_template = self.get_html_template()
        return html_template.format(
            title=self.title,
            favicon_url=self.favicon_url,
            openapi_url=self.openapi_url,
            head_css_str=self.get_head_css_str(),
            head_js_str=self.get_head_js_str(),
            tail_js_str=self.get_tail_js_str(),
        )

    def get_html_template(self) -> str:
        html = """<!doctype html>
        <html lang="en">
            <head>
                <meta charset="utf-8"/>
                <meta name="viewport" content="width=device-width, initial-scale=1, shrink-to-fit=no">
                <title>{title}</title>
                <link rel="shortcut icon" href="{favicon_url}">
                {head_css_str}
                {head_js_str}
            </head>
            <body>
                <noscript>
                    Stoplight Elements requires Javascript to function. Please enable it to browse the documentation.
                </noscript>
                <elements-api apiDescriptionUrl="{openapi_url}" router="hash" layout="sidebar"/>
                {tail_js_str}
            </body>
        </html>"""
        return html



import json
from dataclasses import dataclass

from typing_extensions import Annotated, Any, Dict, Doc, List, Optional

from .base import Base

default_parameters: Annotated[
    Dict[str, Any],
    Doc(
        """
        Default configurations for Swagger UI.
        You can use it as a template to add any other configurations needed.
        """
    ),
] = {
    "dom_id": "#swagger-ui",
    "layout": "BaseLayout",
    "deepLinking": True,
    "showExtensions": True,
    "showCommonExtensions": True,
}
default_parameters_presets: Annotated[
    List[str],
    Doc(
        """
        Default configurations for Swagger UI presets.
        You can use it as a template to add any other configurations needed.
        """
    ),
] = ["SwaggerUIBundle.presets.apis", "SwaggerUIBundle.SwaggerUIStandalonePreset"]


@dataclass
class SwaggerUI(Base):
    """Alternative API docs using Swagger UI."""

    js_url: Annotated[
        str,
        Doc(
            """
            The URL to use to load the Swagger UI JavaScript.
            It is normally set to a CDN URL.
            """
        ),
    ] = "https://cdn.jsdelivr.net/npm/swagger-ui-dist@5.9.0/swagger-ui-bundle.js"
    css_url: Annotated[
        str,
        Doc(
            """
            The URL to use to load the Swagger UI CSS.
            It is normally set to a CDN URL.
            """
        ),
    ] = "https://cdn.jsdelivr.net/npm/swagger-ui-dist@5.9.0/swagger-ui.css"
    oauth2_redirect_url: Annotated[
        Optional[str],
        Doc(
            """
            The OAuth2 redirect URL.
            """
        ),
    ] = "/docs/oauth2-redirect"
    init_oauth: Annotated[
        Optional[Dict[str, Any]],
        Doc(
            """
            A dictionary with Swagger UI OAuth2 initialization configurations.
            """
        ),
    ] = None
    swagger_ui_parameters: Annotated[
        Optional[Dict[str, Any]],
        Doc(
            """
            Configuration parameters for Swagger UI.
            It defaults to [default_parameters][openapipages.swaggerui.default_parameters].
            """
        ),
    ] = None
    swagger_ui_presets: Annotated[
        Optional[List[str]],
        Doc(
            """
            Configuration parameters for Swagger UI presets.
            It defaults to [default_parameters][openapipages.swaggerui.default_parameters].
            """
        ),
    ] = None

    def render(self) -> str:
        """Generate and return the HTML that loads Swagger UI for the alternative API docs."""
        self.head_css_urls.insert(0, self.css_url)
        self.tail_js_urls.insert(0, self.js_url)
        current_swagger_ui_parameters = default_parameters.copy()
        current_swagger_ui_parameters.update({"url": self.openapi_url})
        if self.swagger_ui_parameters:
            current_swagger_ui_parameters.update(self.swagger_ui_parameters)
        current_swagger_ui_presets = default_parameters_presets.copy()
        if self.swagger_ui_presets:
            current_swagger_ui_presets.extend(self.swagger_ui_presets)
        presets = ", ".join(current_swagger_ui_presets)
        html_swagger_ui_parameters = "".join(
            [
                f"{json.dumps(key)}: {json.dumps(value)},"
                for key, value in current_swagger_ui_parameters.items()
            ]
        )
        html_oauth2_redirect_url = (
            f"oauth2RedirectUrl: window.location.origin + '{self.oauth2_redirect_url}',"
            if self.oauth2_redirect_url
            else ""
        )
        init_oauth_html = (
            f"ui.initOAuth({json.dumps(self.init_oauth)})" if self.init_oauth else ""
        )
        html_template = self.get_html_template()
        return html_template.format(
            title=self.title,
            favicon_url=self.favicon_url,
            head_css_str=self.get_head_css_str(),
            head_js_str=self.get_head_js_str(),
            tail_js_str=self.get_tail_js_str(),
            html_swagger_ui_parameters=html_swagger_ui_parameters,
            html_oauth2_redirect_url=html_oauth2_redirect_url,
            presets=presets,
            init_oauth_html=init_oauth_html,
        )

    def get_html_template(self) -> str:
        html = """
        <!DOCTYPE html>
        <html>
            <head>
                <title>{title}</title>
                <link rel="shortcut icon" href="{favicon_url}">
                {head_css_str}
                {head_js_str}
            </head>
            <body>
                <div id="swagger-ui"></div>
                {tail_js_str}
                <!-- `SwaggerUIBundle` is now available on the page -->
                <script>
                    const ui = SwaggerUIBundle({{
                        {html_swagger_ui_parameters}
                        {html_oauth2_redirect_url}
                        presets: [{presets}],
                    }})
                    {init_oauth_html}
                </script>
            </body>
        </html>
        """
        return html



import json
from dataclasses import dataclass

from typing_extensions import Annotated, Any, Dict, Doc, Optional

from .base import Base

default_parameters: Annotated[
    Dict[str, Any],
    Doc(
        """
        Default configurations for Redoc UI.
        You can use it as a template to add any other configurations needed.
        Available options can be found here:
        https://github.com/Redocly/redoc/blob/main/docs/config.md#theme-settings
        """
    ),
] = {
    "theme": {
        "typography": {"code": {"wrap": True}},
    },
    "hide-download-button": False,
}


@dataclass
class ReDoc(Base):
    """Alternative API docs using ReDoc."""

    js_url: Annotated[
        str,
        Doc(
            """
            The URL to use to load the ReDoc JavaScript.
            It is normally set to a CDN URL.
            """
        ),
    ] = "https://cdn.jsdelivr.net/npm/redoc@next/bundles/redoc.standalone.js"
    with_google_fonts: Annotated[
        bool,
        Doc(
            """
            Load and use Google Fonts.
            """
        ),
    ] = True
    ui_parameters: Annotated[
        Optional[Dict[str, Any]],
        Doc(
            """
            Configuration parameters for Redoc UI.
            It defaults to [redoc_ui_default_parameters][fastapi.openapi.docs.redoc_ui_default_parameters].
            """
        ),
    ] = None

    def render(self) -> str:
        """Generate and return the HTML response that loads ReDoc for the alternative API docs."""
        self.tail_js_urls.insert(0, self.js_url)
        google_fonts_str = ""
        if self.with_google_fonts:
            google_fonts_str = """<link href="https://fonts.googleapis.com/css?family=Montserrat:300,400,700|Roboto:300,400,700" rel="stylesheet">"""

        current_redoc_ui_parameters = default_parameters.copy()
        current_redoc_ui_parameters.update(self.ui_parameters or {})

        def add_redoc_ui_parameters() -> str:
            _props = ""
            for key, value in current_redoc_ui_parameters.items():
                if value:
                    _props += f"{key}='{json.dumps(value)}' "
                else:
                    _props += f"{key} "
            return _props

        html_template = self.get_html_template()
        return html_template.format(
            title=self.title,
            favicon_url=self.favicon_url,
            openapi_url=self.openapi_url,
            head_css_str=self.get_head_css_str(),
            head_js_str=self.get_head_js_str(),
            tail_js_str=self.get_tail_js_str(),
            google_fonts_str=google_fonts_str,
            redoc_ui_parameters=add_redoc_ui_parameters(),
        )

    def get_html_template(self) -> str:
        html = """
        <!DOCTYPE html>
        <html>
            <head>
                <meta charset="utf-8"/>
                <meta name="viewport" content="width=device-width, initial-scale=1">
                <title>{title}</title>
                <link rel="shortcut icon" href="{favicon_url}">
                {google_fonts_str}
                {head_css_str}
                {head_js_str}
                <!-- ReDoc doesn't change outer page styles -->
                <style>
                    body {{
                        margin: 0;
                        padding: 0;
                    }}
                </style>
            </head>
            <body>
                <noscript>
                    ReDoc requires Javascript to function. Please enable it to browse the documentation.
                </noscript>
                <redoc spec-url="{openapi_url}" {redoc_ui_parameters}></redoc>
                {tail_js_str}
            </body>
        </html>
        """
        return html



from fastapi import FastAPI
from fastapi.responses import HTMLResponse
from openapipages import Elements, RapiDoc, ReDoc, Scalar, SwaggerUI
from typing_extensions import Dict

app = FastAPI()


@app.get("/")
def root() -> Dict[str, str]:
    return {"Hello": "World"}


@app.get("/swaggerui-plain", response_class=HTMLResponse, include_in_schema=False)
def get_swaggerui_plain() -> str:
    return SwaggerUI(title="Swagger UI").render()


@app.get("/swaggerui-custom", response_class=HTMLResponse, include_in_schema=False)
def get_swaggerui_custom() -> str:
    return SwaggerUI(
        title="Swagger UI",
        js_url="https://unpkg.com/swagger-ui-dist@5.9.0/swagger-ui-bundle.js",
        css_url="https://unpkg.com/swagger-ui-dist@5.9.0/swagger-ui.css",
        init_oauth={
            "clientId": "the-application-clients",
            "appName": "Test Application",
        },
        oauth2_redirect_url=None,
        swagger_ui_parameters={
            "syntaxHighlight": False,
            "syntaxHighlight.theme": "obsidian",
            "deepLinking": False,
        },
    ).render()


@app.get("/redoc-plain", response_class=HTMLResponse, include_in_schema=False)
def get_redoc_plain() -> str:
    return ReDoc(title="ReDoc").render()


@app.get("/redoc-custom", response_class=HTMLResponse, include_in_schema=False)
def get_redoc_custom() -> str:
    return ReDoc(
        title="ReDoc", js_url="https://unpkg.com/redoc@next/bundles/redoc.standalone.js"
    ).render()


@app.get("/scalar-plain", response_class=HTMLResponse, include_in_schema=False)
def get_scalar_plain() -> str:
    return Scalar(title="Scalar").render()


@app.get("/scalar-custom", response_class=HTMLResponse, include_in_schema=False)
def get_scalar_custom() -> str:
    return Scalar(
        title="Scalar",
        js_url="https://cdn.jsdelivr.net/npm/@scalar/api-reference",
    ).render()


@app.get("/elements", response_class=HTMLResponse, include_in_schema=False)
def get_elements() -> str:
    return Elements(title="Elements").render()


@app.get("/rapidoc", response_class=HTMLResponse, include_in_schema=False)
def get_rapidoc() -> str:
    return RapiDoc(title="RapiDoc").render()



from fastapi.testclient import TestClient

from .main import app

client = TestClient(app)


def test_redoc_plain() -> None:
    # Copy of  https://github.com/tiangolo/fastapi/blob/be876902554a0bd886167de144f0d593ed2e6ad7/tests/test_application.py#L42-L46
    response = client.get("/redoc-plain")
    assert response.status_code == 200, response.text
    assert response.headers["content-type"] == "text/html; charset=utf-8"
    assert "redoc@next" in response.text


def test_redoc_custom() -> None:
    # Copy of  https://github.com/tiangolo/fastapi/blob/be876902554a0bd886167de144f0d593ed2e6ad7/tests/test_tutorial/test_custom_docs_ui/test_tutorial001.py#L35-L38
    response = client.get("/redoc-custom")
    assert response.status_code == 200, response.text
    assert "https://unpkg.com/redoc@next/bundles/redoc.standalone.js" in response.text



from litestar import Litestar, MediaType, get
from openapipages import Elements, RapiDoc, ReDoc, Scalar, SwaggerUI

openapi_url = "/schema/openapi.json"


@get("/")
def root() -> dict[str, str]:
    return {"Hello": "World"}


@get("/swaggerui", media_type=MediaType.HTML, include_in_schema=False)
def get_swaggerui() -> str:
    return SwaggerUI(title="Swagger UI", openapi_url=openapi_url).render()


@get("/redoc", media_type=MediaType.HTML, include_in_schema=False)
def get_redoc() -> str:
    return ReDoc(title="ReDoc", openapi_url=openapi_url).render()


@get("/scalar", media_type=MediaType.HTML, include_in_schema=False)
def get_scalar() -> str:
    return Scalar(title="Scalar", openapi_url=openapi_url).render()


@get("/elements", media_type=MediaType.HTML, include_in_schema=False)
def get_elements() -> str:
    return Elements(title="Elements", openapi_url=openapi_url).render()


@get("/rapidoc", media_type=MediaType.HTML, include_in_schema=False)
def get_rapidoc() -> str:
    return RapiDoc(title="RapiDoc", openapi_url=openapi_url).render()


app = Litestar([root, get_swaggerui, get_redoc, get_scalar, get_elements, get_rapidoc])



from fastapi import FastAPI
from fastapi.responses import HTMLResponse
from openapipages import Elements, RapiDoc, ReDoc, Scalar, SwaggerUI
from typing_extensions import Dict

app = FastAPI()


@app.get("/")
def root() -> Dict[str, str]:
    return {"Hello": "World"}


@app.get("/swaggerui", response_class=HTMLResponse, include_in_schema=False)
def get_swaggerui() -> str:
    return SwaggerUI(title="Swagger UI").render()


@app.get("/redoc", response_class=HTMLResponse, include_in_schema=False)
def get_redoc() -> str:
    return ReDoc(title="ReDoc").render()


@app.get("/scalar", response_class=HTMLResponse, include_in_schema=False)
def get_scalar() -> str:
    return Scalar(title="Scalar").render()


@app.get("/elements", response_class=HTMLResponse, include_in_schema=False)
def get_elements() -> str:
    return Elements(title="Elements").render()


@app.get("/rapidoc", response_class=HTMLResponse, include_in_schema=False)
def get_rapidoc() -> str:
    return RapiDoc(title="RapiDoc").render()



from dataclasses import dataclass

from typing_extensions import Annotated, Doc

from .base import Base


@dataclass
class Scalar(Base):
    """Alternative API docs using Scalar."""

    js_url: Annotated[
        str,
        Doc(
            """
            The URL to use to load the Scalar JavaScript.
            It is normally set to a CDN URL.
            """
        ),
    ] = "https://cdn.jsdelivr.net/npm/@scalar/api-reference"
    proxy_url: Annotated[
        str,
        Doc(
            """
            The URL to use to set the Scalar Proxy.
            It is normally set to a Scalar API URL (https://api.scalar.com/request-proxy), but default is empty.
            """
        ),
    ] = ""

    def render(self) -> str:
        """Generate and return the HTML response that loads Scalar for the alternative API docs."""
        self.tail_js_urls.insert(0, self.js_url)
        html_template = self.get_html_template()
        return html_template.format(
            title=self.title,
            favicon_url=self.favicon_url,
            openapi_url=self.openapi_url,
            proxy_url=self.proxy_url,
            head_css_str=self.get_head_css_str(),
            head_js_str=self.get_head_js_str(),
            tail_js_str=self.get_tail_js_str(),
        )

    def get_html_template(self) -> str:
        html = """
        <!DOCTYPE html>
        <html>
            <head>
                <meta charset="utf-8"/>
                <meta name="viewport" content="width=device-width, initial-scale=1">
                <title>{title}</title>
                <link rel="shortcut icon" href="{favicon_url}">
                {head_css_str}
                {head_js_str}
                <style>
                    body {{
                        margin: 0;
                        padding: 0;
                    }}
                </style>
            </head>
            <body>
                <noscript>
                    Scalar requires Javascript to function. Please enable it to browse the documentation.
                </noscript>
                <script id="api-reference" data-url="{openapi_url}" data-proxy-url="{proxy_url}"></script>
                {tail_js_str}
            </body>
        </html>
        """
        return html



from fastapi.testclient import TestClient

from .main import app

client = TestClient(app)


def test_rapidoc() -> None:
    response = client.get("/rapidoc")
    assert response.status_code == 200, response.text
    assert response.headers["content-type"] == "text/html; charset=utf-8"
    assert "rapidoc/dist/rapidoc-min.js" in response.text
